@@ -1,4 +1,4 @@
-# $Id: Apache.pm,v 1.3 2002/02/02 04:08:19 m_ilya Exp $
+# $Id: Apache.pm,v 1.4 2002/05/12 13:35:35 m_ilya Exp $
 
 package HTTP::WebTest::Plugin::Apache;
 
@@ -12,8 +12,8 @@ Not Applicable
 
 =head1 DESCRIPTION
 
-This plugin provides support for local web file test mode. Apache must
-be installed to run tests in this mode.
+This plugin provides support for local web file test mode.  Apache
+must be installed to run tests in this mode.
 
 =for pod_merge copy apache
 
@@ -23,16 +23,16 @@ A tree of directories with templates of Apache config files is
 required to run local web file tests.
 
 The C<apache_dir> parameter must be set to the name of a directory
-that contains the subdirectories C<conf>, C<logs> and C<htdocs>. The
-C<conf> subdirectory must contain a file named C<httpd.conf-dist>. The
-C<htdocs> subdirectory must contain a subdirectory named C<webtest>
-that contains a file named C<is_apache_responding.html>. If your
-installation of Apache has the Perl module L<Apache::ASP|Apache::ASP>
-configured, the C<apache_dir> directory must also contain a
-subdirectory named C<asp_tmp>.
+that contains the subdirectories C<conf>, C<logs> and C<htdocs>.  The
+C<conf> subdirectory must contain a file named C<httpd.conf-dist>.
+The C<htdocs> subdirectory must contain a subdirectory named
+C<webtest> that contains a file named C<is_apache_responding.html>.
+If your installation of Apache has the Perl module
+L<Apache::ASP|Apache::ASP> configured, the C<apache_dir> directory
+must also contain a subdirectory named C<asp_tmp>.
 
 The file C<httpd.conf-dist> is used as template for the Apache config
-file. It contains tags which are replaced with the values needed by
+file.  It contains tags which are replaced with the values needed by
 the Apache server that the program starts at runtime.
 
 =over 4
@@ -83,10 +83,10 @@ use base qw(HTTP::WebTest::Plugin);
 
 I<GLOBAL PARAMETER>
 
-Absolute or relative path name of directory containing
-Apache files. See the
-L<APACHE DIRECTORY AND FILES|/"APACHE DIRECTORY AND FILES"> section.
-This parameter is ignored unless the C<file_path> parameter is specified.
+Absolute or relative path name of directory containing Apache files.
+See the L<APACHE DIRECTORY AND FILES|/"APACHE DIRECTORY AND FILES">
+section.  This parameter is ignored unless the C<file_path> parameter
+is specified.
 
 =head3 Default value
 
@@ -96,9 +96,9 @@ C</usr/local/etc/http-webtest>
 
 I<GLOBAL PARAMETER>
 
-Absolute or relative path name of Apache executable. This command can
-be in your C<$PATH>. This parameter is ignored unless the C<file_path>
-parameter is specified.
+Absolute or relative path name of Apache executable.  This command can
+be in your C<$PATH>.  This parameter is ignored unless the
+C<file_path> parameter is specified.
 
 =head3 Default value
 
@@ -108,10 +108,10 @@ C</usr/sbin/apache>
 
 I<GLOBAL PARAMETER>
 
-Apache logging level. If you use a level less than C<warn> (i.e.,
+Apache logging level.  If you use a level less than C<warn> (i.e.,
 C<debug>, C<info>, or C<notice>), the program may generate irrelevant
-errors. This parameter is ignored unless the C<file_path> parameter is
-specified. See also the C<ignore_error_log> parameter.
+errors.  This parameter is ignored unless the C<file_path> parameter
+is specified.  See also the C<ignore_error_log> parameter.
 
 =head3 Allowed values
 
@@ -126,7 +126,7 @@ C<warn>
 
 I<GLOBAL PARAMETER>
 
-Maximum number of seconds to wait for Apache to start. This parameter
+Maximum number of seconds to wait for Apache to start.  This parameter
 is ignored unless the C<file_path> parameter is specified.
 
 =head3 Default value
@@ -137,10 +137,10 @@ C<60>
 
 I<GLOBAL PARAMETER>
 
-Additional Apache command line options. Many of the options cause
+Additional Apache command line options.  Many of the options cause
 Apache to exit immediately after starting, so the web page tests will
-not run. This parameter is ignored unless the C<file_path> parameter is
-specified.
+not run.  This parameter is ignored unless the C<file_path> parameter
+is specified.
 
 =head3 Allowed values
 
@@ -150,38 +150,38 @@ See Apache documentation
 
 I<GLOBAL PARAMETER>
 
-The pathname of a local web server error log. The module counts the
-number of lines in the error log before and after each request. If the
-number of lines increases, an error is counted and the additional
-lines are listed in the report. This argument should be used only when
-the local web server is running in single-process mode. Otherwise,
-requests generated by other processes/users may add lines to the error
-log that are not related to the requests generated by this module. See
-also parameter C<ignore_error_log>.
+The pathname of a local web server error log.  The module counts the
+number of lines in the error log before and after each request.  If
+the number of lines increases, an error is counted and the additional
+lines are listed in the report.  This argument should be used only
+when the local web server is running in single-process mode.
+Otherwise, requests generated by other processes/users may add lines
+to the error log that are not related to the requests generated by
+this module.  See also parameter C<ignore_error_log>.
 
 =head2 file_path
 
 If L<HTTP::WebTest|HTTP::WebTest> encounters parameter C<file_path> it
-switches in local web file test mode. In local web file test mode it
+switches in local web file test mode.  In local web file test mode it
 launches an instance of Apache daemon, copies local test file(s) under
 DocumentRoot of this Apache and performs test checks against it.
 
 =head3 Allowed values
 
-Two-element list. First element is the file to test, either an
-absolute or a relative pathname. Second element is the subdirectory
+Two-element list.  First element is the file to test, either an
+absolute or a relative pathname.  Second element is the subdirectory
 pathname, relative to the Apache htdocs directory, to copy the file
-to. The copied file will have the same basename as the first element
-and the relative pathname of the second element. To copy the file
+to.  The copied file will have the same basename as the first element
+and the relative pathname of the second element.  To copy the file
 directly to the htdocs directory, use a pathname of C<.> or C<./.>.
 
 =head2 ignore_error_log
 
-Option to ignore any errors found in the Apache error log. The default
-behavior is to flag an error if the fetch causes any errors to be
-added to the error log and echo the errors to the program output. This
-check is available only if C<error_log> parameter is specified. See also
-the C<apache_loglevel> parameter.
+Option to ignore any errors found in the Apache error log.  The
+default behavior is to flag an error if the fetch causes any errors to
+be added to the error log and echo the errors to the program output.
+This check is available only if C<error_log> parameter is specified.
+See also the C<apache_loglevel> parameter.
 
 =head3 Allowed values
 
@@ -193,12 +193,12 @@ C<no>
 
 =head2 include_file_path
 
-List with an even number of elements. Odd-numbered elements are files
+List with an even number of elements.  Odd-numbered elements are files
 to copy to the the temporary Apache directory before running the
-tests. These files can be specified using either an absolute or a
-relative pathname. Even-numbered elements are the subdirectory
+tests.  These files can be specified using either an absolute or a
+relative pathname.  Even-numbered elements are the subdirectory
 pathname, relative to the Apache ServerRoot directory, to copy the
-corresponding file to. The copied file will have the same basename as
+corresponding file to.  The copied file will have the same basename as
 the odd-numbered element and the relative pathname of the
 corresponding even-numbered element.  To copy the file directly to the
 ServerRoot directory, use a pathname of C<.> or C<./.>.
@@ -209,9 +209,8 @@ For example:
 
 will copy the file to htdocs/includes/header.inc.
 
-This parameter is also useful for adding Perl modules that are
-needed by the web page specified by the file_path parameter. For
-example:
+This parameter is also useful for adding Perl modules that are needed
+by the web page specified by the file_path parameter.  For example:
 
     include_file_path = ( ../apps/myapp/DBconn.pm => lib/perl/apps )
 
@@ -388,7 +387,7 @@ sub check_apache {
 }
 
 # forks a child process that starts Apache in on a random
-# private/dynamic port number. Verifies that Apache has started by
+# private/dynamic port number.  Verifies that Apache has started by
 # fetching a test page and searching the fetched page for a tag line.
 sub start_apache {
     my $self = shift;
@@ -542,9 +541,9 @@ sub verify_apache {
 }
 
 # copy a file to a root directory concatenated with a relative
-# pathname, creating directories as needed. The basename of the file
-# is preserved. Returns pathname of file that was created, relative to
-# root directory
+# pathname, creating directories as needed.  The basename of the file
+# is preserved.  Returns pathname of file that was created, relative
+# to root directory
 sub copy_file {
     my $self = shift;
     # file to copy
@@ -592,9 +591,9 @@ sub DESTROY {
 
 =head1 COPYRIGHT
 
-Copyright (c) 2000-2001 Richard Anderson. All rights reserved.
+Copyright (c) 2000-2001 Richard Anderson.  All rights reserved.
 
-Copyright (c) 2001,2002 Ilya Martynov. All rights reserved.
+Copyright (c) 2001,2002 Ilya Martynov.  All rights reserved.
 
 This module is free software.  It may be used, redistributed and/or
 modified under the terms of the Perl Artistic License.
